==> nextcloud-31.0.9.tgz: nextcloud/apps/workflowengine/l10n/sw.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Opereta uliyopewa si sahihi",
    "The given regular expression is invalid" : "Msemo wa kawaida uliotolewa si sahihi",
    "The given file size is invalid" : "Ukubwa wa faili uliotolewa si sahihi",
    "The given tag id is invalid" : "Kitambulisho cha lebo kilichotolewa si sahihi",
    "The given IP range is invalid" : "Anuwai ya IP iliyotolewa si sahihi",
    "The given IP range is not valid for IPv4" : "Anuwai ya IP iliyotolewa si halali kwa IPv4",
    "The given IP range is not valid for IPv6" : "Anuwai ya IP iliyotolewa si halali kwa IPv6",
    "The given time span is invalid" : "Muda uliyopewa si sahihi",
    "The given start time is invalid" : "Muda wa kuanza uliyopewa si sahihi",
    "The given end time is invalid" : "Muda wa kumaliza uliyopewa ni batili",
    "The given group does not exist" : "Kundi lililotolewa halipo",
    "File" : "Faili",
    "File created" : "Faili imeundwa",
    "File updated" : "Faili imesasishwa",
    "File renamed" : "Faili imepewa jina upya",
    "File deleted" : "Faili imefutwa",
    "File accessed" : "Faili imefikiwa",
    "File copied" : "Faili imenakiliwa",
    "Tag assigned" : "Lebo imetolewa",
    "Someone" : "Mtu fulani",
    "%s created %s" : "%s imeundwa %s",
    "%s modified %s" : "%s imeboreshwa %s",
    "%s deleted %s" : "%s imefutwa %s",
    "%s accessed %s" : "%s imefikiwa %s",
    "%s renamed %s" : "%s imepewa jina jipya %s",
    "%s copied %s" : "%s imenakiliwa %s",
    "%s assigned %s to %s" : "%simekabidhiwa  %s kwa %s",
    "Operation #%s does not exist" : "Operesheni #%s haipo",
    "Entity %s does not exist" : "Huluki %s haipo",
    "Entity %s is invalid" : "Huluki %s si sahihi",
    "No events are chosen." : "Hakuna matukio yaliyochaguliwa.",
    "Entity %s has no event %s" : "Huluki %s haina tukio %s",
    "Operation %s does not exist" : "Operesheni %s haipo",
    "Operation %s is invalid" : "Operesheni %s si sahihi",
    "At least one check needs to be provided" : "Angalau hundi moja inahitaji kutolewa",
    "The provided operation data is too long" : "Taarifa za operesheni zilizotolewa ni ndefu sana",
    "Invalid check provided" : "Hundi batili imetolewa",
    "Check %s does not exist" : "Angalia %s haipo",
    "Check %s is invalid" : "Angalia %s si sahihi",
    "Check %s is not allowed with this entity" : "Kukagua %s hairuhusiwi na huluki hii",
    "The provided check value is too long" : "Thamani ya hundi iliyotolewa ni ndefu sana",
    "Check #%s does not exist" : "Ukaguzi #%s haupo",
    "Check %s is invalid or does not exist" : "Angalia %s si sahihi au haipo",
    "Flow" : "Mtiririko",
    "Nextcloud workflow engine" : "Injini ya mtiririko wa kazi ya Nextcloud",
    "Select a filter" : "Chagua kichujio",
    "Select a comparator" : "Chagua kipimajoto",
    "Remove filter" : "Ondoa kichujio",
    "Folder" : "Kisanduku",
    "Images" : "Picha",
    "Office documents" : "Nyaraka za ofisi",
    "PDF documents" : "Nyaraka za PDF",
    "Custom MIME type" : "Aina ya MIME ya kawaida",
    "Custom mimetype" : "Aina maalum ya mime",
    "Select a file type" : "Chagua aina ya faili",
    "e.g. httpd/unix-directory" : "e.g. httpd/unix-directory",
    "Please enter a valid time span" : "Tafadhali ingiza muda halali",
    "Files WebDAV" : "Faili za WebDAV",
    "Custom URL" : "URL maalum",
    "Select a request URL" : "Chagua URL ya ombi",
    "Android client" : "Mteja wa Android",
    "iOS client" : "Mteja wa iOS",
    "Desktop client" : "Mteja wa eneo-kazi",
    "Thunderbird & Outlook addons" : "Viongezeo vya Thunderbird na Outlook",
    "Custom user agent" : "Wakala maalum wa mtumiaji ",
    "Select a user agent" : "Chagua wakala wa mtumiaji",
    "Select groups" : "Chagua makundi",
    "Groups" : "Makundi",
    "Type to search for group …" : "Andika kutafuta kikundi …",
    "Select a trigger" : "Chagua kichocheo",
    "At least one event must be selected" : "Angalau tukio moja lazima lichaguliwe",
    "Add new flow" : "Ongeza mtiririko mpya",
    "The configuration is invalid" : "Usanidi si sahihi",
    "Active" : "Hai",
    "Save" : "Hifadhi",
    "When" : "Lini",
    "and" : "na",
    "Add a new filter" : "Ongeza kichujio kipya",
    "Cancel" : "Sitisha",
    "Delete" : "Futa",
    "Available flows" : "Mitiririko inayopatikana",
    "For details on how to write your own flow, check out the development documentation." : "Kwa maelezo kuhusu jinsi ya kuandika mtiririko wako mwenyewe, angalia nyaraka za maendeleo.",
    "No flows installed" : "Hakuna mtiririko uliowekwa",
    "Ask your administrator to install new flows." : "Muulize msimamizi wako aweke mitiririko mipya.",
    "More flows" : "Mtiririko zaidi",
    "Browse the App Store" : "Vinjari hifadhi ya Programu",
    "Show less" : "Onesha kidogo",
    "Show more" : "Onesha zaidi",
    "Configured flows" : "Mitiririko iliyosanidiwa",
    "Your flows" : "Mitiririko yako",
    "No flows configured" : "Hakuna mitiririko iliyosanidiwa",
    "matches" : "inafanana",
    "does not match" : "haifanani",
    "is" : "ni",
    "is not" : "si",
    "File name" : "Jina la faili",
    "File MIME type" : "Aina ya MIME ya faili",
    "File size (upload)" : "Ukubwa wa faili (kupakia)",
    "less" : "chini",
    "less or equals" : "chini au sawa na",
    "greater or equals" : "kubwa au sawa na",
    "greater" : "kubwa",
    "Request remote address" : "Omba anwani ya mbali",
    "matches IPv4" : "Inafanana na IPv4",
    "does not match IPv4" : "haifanani na IPv4",
    "matches IPv6" : "inafanana na IPv6",
    "does not match IPv6" : "haifanani na IPv6",
    "File system tag" : "Lebo ya mfumo wa faili",
    "is tagged with" : "Imewekewa alama na",
    "is not tagged with" : "haijawekewa alama na",
    "Request URL" : "Omba URL",
    "Request time" : "Muda wa ombi",
    "between" : "kati ya",
    "not between" : "si kati ya",
    "Request user agent" : "Omba wakala wa mtumiaji",
    "Group membership" : "Uanachama wa kikundi",
    "is member of" : "ni mwanachama wa",
    "is not member of" : "si mwanachama wa"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.10.tgz: nextcloud/apps/workflowengine/l10n/sw.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Opereta uliyopewa si sahihi",
    "The given regular expression is invalid" : "Msemo wa kawaida uliotolewa si sahihi",
    "The given file size is invalid" : "Ukubwa wa faili uliotolewa si sahihi",
    "The given tag id is invalid" : "Kitambulisho cha lebo kilichotolewa si sahihi",
    "The given IP range is invalid" : "Anuwai ya IP iliyotolewa si sahihi",
    "The given IP range is not valid for IPv4" : "Anuwai ya IP iliyotolewa si halali kwa IPv4",
    "The given IP range is not valid for IPv6" : "Anuwai ya IP iliyotolewa si halali kwa IPv6",
    "The given time span is invalid" : "Muda uliyopewa si sahihi",
    "The given start time is invalid" : "Muda wa kuanza uliyopewa si sahihi",
    "The given end time is invalid" : "Muda wa kumaliza uliyopewa ni batili",
    "The given group does not exist" : "Kundi lililotolewa halipo",
    "File" : "Faili",
    "File created" : "Faili imeundwa",
    "File updated" : "Faili imesasishwa",
    "File renamed" : "Faili imepewa jina upya",
    "File deleted" : "Faili imefutwa",
    "File accessed" : "Faili imefikiwa",
    "File copied" : "Faili imenakiliwa",
    "Tag assigned" : "Lebo imetolewa",
    "Someone" : "Mtu fulani",
    "%s created %s" : "%s imeundwa %s",
    "%s modified %s" : "%s imeboreshwa %s",
    "%s deleted %s" : "%s imefutwa %s",
    "%s accessed %s" : "%s imefikiwa %s",
    "%s renamed %s" : "%s imepewa jina jipya %s",
    "%s copied %s" : "%s imenakiliwa %s",
    "%s assigned %s to %s" : "%simekabidhiwa  %s kwa %s",
    "Operation #%s does not exist" : "Operesheni #%s haipo",
    "Entity %s does not exist" : "Huluki %s haipo",
    "Entity %s is invalid" : "Huluki %s si sahihi",
    "No events are chosen." : "Hakuna matukio yaliyochaguliwa.",
    "Entity %s has no event %s" : "Huluki %s haina tukio %s",
    "Operation %s does not exist" : "Operesheni %s haipo",
    "Operation %s is invalid" : "Operesheni %s si sahihi",
    "At least one check needs to be provided" : "Angalau hundi moja inahitaji kutolewa",
    "The provided operation data is too long" : "Taarifa za operesheni zilizotolewa ni ndefu sana",
    "Invalid check provided" : "Hundi batili imetolewa",
    "Check %s does not exist" : "Angalia %s haipo",
    "Check %s is invalid" : "Angalia %s si sahihi",
    "Check %s is not allowed with this entity" : "Kukagua %s hairuhusiwi na huluki hii",
    "The provided check value is too long" : "Thamani ya hundi iliyotolewa ni ndefu sana",
    "Check #%s does not exist" : "Ukaguzi #%s haupo",
    "Check %s is invalid or does not exist" : "Angalia %s si sahihi au haipo",
    "Flow" : "Mtiririko",
    "Nextcloud workflow engine" : "Injini ya mtiririko wa kazi ya Nextcloud",
    "Select a filter" : "Chagua kichujio",
    "Select a comparator" : "Chagua kipimajoto",
    "Remove filter" : "Ondoa kichujio",
    "Audio" : "Sauti",
    "Folder" : "Kisanduku",
    "Images" : "Picha",
    "Office documents" : "Nyaraka za ofisi",
    "PDF documents" : "Nyaraka za PDF",
    "Video" : "Video",
    "Custom MIME type" : "Aina ya MIME ya kawaida",
    "Custom mimetype" : "Aina maalum ya mime",
    "Select a file type" : "Chagua aina ya faili",
    "e.g. httpd/unix-directory" : "e.g. httpd/unix-directory",
    "Please enter a valid time span" : "Tafadhali ingiza muda halali",
    "Files WebDAV" : "Faili za WebDAV",
    "Custom URL" : "URL maalum",
    "Select a request URL" : "Chagua URL ya ombi",
    "Android client" : "Mteja wa Android",
    "iOS client" : "Mteja wa iOS",
    "Desktop client" : "Mteja wa eneo-kazi",
    "Thunderbird & Outlook addons" : "Viongezeo vya Thunderbird na Outlook",
    "Custom user agent" : "Wakala maalum wa mtumiaji ",
    "Select a user agent" : "Chagua wakala wa mtumiaji",
    "Select groups" : "Chagua makundi",
    "Groups" : "Makundi",
    "Select a trigger" : "Chagua kichocheo",
    "At least one event must be selected" : "Angalau tukio moja lazima lichaguliwe",
    "Add new flow" : "Ongeza mtiririko mpya",
    "The configuration is invalid" : "Usanidi si sahihi",
    "Active" : "Hai",
    "Save" : "Hifadhi",
    "When" : "Lini",
    "and" : "na",
    "Add a new filter" : "Ongeza kichujio kipya",
    "Cancel" : "Sitisha",
    "Delete" : "Futa",
    "Available flows" : "Mitiririko inayopatikana",
    "For details on how to write your own flow, check out the development documentation." : "Kwa maelezo kuhusu jinsi ya kuandika mtiririko wako mwenyewe, angalia nyaraka za maendeleo.",
    "No flows installed" : "Hakuna mtiririko uliowekwa",
    "Ask your administrator to install new flows." : "Muulize msimamizi wako aweke mitiririko mipya.",
    "More flows" : "Mtiririko zaidi",
    "Browse the App Store" : "Vinjari hifadhi ya Programu",
    "Show less" : "Onesha kidogo",
    "Show more" : "Onesha zaidi",
    "Configured flows" : "Mitiririko iliyosanidiwa",
    "Your flows" : "Mitiririko yako",
    "No flows configured" : "Hakuna mitiririko iliyosanidiwa",
    "matches" : "inafanana",
    "does not match" : "haifanani",
    "is" : "ni",
    "is not" : "si",
    "File name" : "Jina la faili",
    "File MIME type" : "Aina ya MIME ya faili",
    "File size (upload)" : "Ukubwa wa faili (kupakia)",
    "less" : "chini",
    "less or equals" : "chini au sawa na",
    "greater or equals" : "kubwa au sawa na",
    "greater" : "kubwa",
    "Request remote address" : "Omba anwani ya mbali",
    "matches IPv4" : "Inafanana na IPv4",
    "does not match IPv4" : "haifanani na IPv4",
    "matches IPv6" : "inafanana na IPv6",
    "does not match IPv6" : "haifanani na IPv6",
    "File system tag" : "Lebo ya mfumo wa faili",
    "is tagged with" : "Imewekewa alama na",
    "is not tagged with" : "haijawekewa alama na",
    "Request URL" : "Omba URL",
    "Request time" : "Muda wa ombi",
    "between" : "kati ya",
    "not between" : "si kati ya",
    "Request user agent" : "Omba wakala wa mtumiaji",
    "Group membership" : "Uanachama wa kikundi",
    "is member of" : "ni mwanachama wa",
    "is not member of" : "si mwanachama wa",
    "Type to search for group …" : "Andika kutafuta kikundi …"
},
"nplurals=2; plural=(n != 1);");
